@@ -28,6 +28,8 @@ pub(crate) struct ItemsSpec {
     pub(crate) datasets: HashMap<String, DatasetSpecs>,
     #[deref]
     pub(crate) default_view: Option<String>,
+    #[serde(default = "default_single_page_threshold")]
+    pub(crate) max_in_memory_rows: usize,
     pub(crate) views: HashMap<String, ItemSpecs>,
 }
 
@@ -45,7 +47,7 @@ impl ItemsSpec {
                         })
                     }
                 };
-                spec.preprocess_columns(dataset)?;
+                spec.preprocess_columns(dataset, items_spec.max_in_memory_rows)?;
             }
         }
         Ok(items_spec)
@@ -86,10 +88,18 @@ impl ItemsSpec {
                     if render_columns.custom_plot.is_some() {
                         possible_conflicting.push("custom-plot".to_string());
                     }
-                    if render_columns.plot.is_some() {
-                        possible_conflicting.push("plot".to_string());
+                    if let Some(plot) = &render_columns.plot {
+                        if plot.heatmap.is_some() {
+                            possible_conflicting.push("heatmap".to_string());
+                        } else if plot.tick_plot.is_some() {
+                            possible_conflicting.push("ticks".to_string());
+                        }
                     }
-                    if possible_conflicting.len() > 1 {
+                    if possible_conflicting.len() > 1
+                        && !(possible_conflicting.contains(&"heatmap".to_string())
+                            && possible_conflicting.contains(&"ellipsis".to_string())
+                            && possible_conflicting.len() == 2)
+                    {
                         bail!(ConflictingConfiguration {
                             view: name.to_string(),
                             column: column.to_string(),
@@ -169,6 +179,10 @@ impl ItemsSpec {
     }
 }
 
+fn default_single_page_threshold() -> usize {
+    1000_usize
+}
+
 fn default_separator() -> char {
     char::from_str(",").unwrap()
 }
@@ -209,14 +223,14 @@ pub(crate) struct ItemSpecs {
     pub(crate) dataset: String,
     #[serde(default = "default_page_size")]
     pub(crate) page_size: usize,
-    #[serde(default)]
-    pub(crate) pin_columns: usize,
     #[serde(rename = "desc")]
     pub(crate) description: Option<String>,
     #[serde(default = "default_render_table")]
     pub(crate) render_table: Option<HashMap<String, RenderColumnSpec>>,
     #[serde(default)]
     pub(crate) render_plot: Option<RenderPlotSpec>,
+    #[serde(default)]
+    pub(crate) max_in_memory_rows: Option<usize>,
 }
 
 lazy_static! {
@@ -229,14 +243,21 @@ lazy_static! {
 
 impl ItemSpecs {
     /// Preprocesses columns with index and regex notation
-    fn preprocess_columns(&mut self, dataset: &DatasetSpecs) -> Result<()> {
+    fn preprocess_columns(
+        &mut self,
+        dataset: &DatasetSpecs,
+        single_page_threshold: usize,
+    ) -> Result<()> {
         let mut indexed_keys = HashMap::new();
         let mut reader = csv::ReaderBuilder::new()
             .delimiter(dataset.separator as u8)
             .from_path(&dataset.path)
             .context(format!("Could not read file with path {:?}", &dataset.path))?;
+        let rows = &reader.records().count();
+        if rows <= &single_page_threshold {
+            self.page_size = *rows;
+        }
         let headers = reader.headers()?;
-
         for (key, render_column_specs) in self.render_table.as_ref().unwrap().iter() {
             let get_first_match_group = |regex: &Regex| {
                 regex
@@ -356,6 +377,8 @@ pub(crate) struct LinkSpec {
     pub(crate) view: Option<String>,
     #[serde(default)]
     pub(crate) table_row: Option<String>,
+    #[serde(default)]
+    pub(crate) optional: bool,
 }
 
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq)]
@@ -510,18 +533,19 @@ mod tests {
             hidden: false,
             dataset: "table-a".to_string(),
             page_size: 100,
-            pin_columns: 1,
             description: None,
             render_table: Some(HashMap::from([(
                 String::from("x"),
                 expected_render_columns,
             )])),
             render_plot: None,
+            max_in_memory_rows: None,
         };
 
         let expected_config = ItemsSpec {
             datasets: HashMap::from([(String::from("table-a"), expected_dataset_spec)]),
             default_view: None,
+            max_in_memory_rows: 1000,
             views: HashMap::from([(String::from("table-a"), expected_table_spec)]),
             report_name: "my_report".to_string(),
         };
@@ -535,7 +559,6 @@ mod tests {
         table-a:
             dataset: table-a
             page-size: 100
-            pin-columns: 1
             render-table:
                 x:
                     link-to-url: https://www.rust-lang.org
@@ -560,6 +583,7 @@ mod tests {
                 column: "test".to_string(),
                 view: Some("other-table".to_string()),
                 table_row: None,
+                optional: false,
             },
         )]);
 
@@ -574,15 +598,16 @@ mod tests {
             hidden: false,
             dataset: "table-a".to_string(),
             page_size: 100,
-            pin_columns: 0,
             description: Some("my table".parse().unwrap()),
             render_table: default_render_table(),
             render_plot: Some(expected_render_plot),
+            max_in_memory_rows: None,
         };
 
         let expected_config = ItemsSpec {
             datasets: HashMap::from([(String::from("table-a"), expected_dataset_spec)]),
             default_view: Some("table-a".to_string()),
+            max_in_memory_rows: 1000,
             views: HashMap::from([(String::from("plot-a"), expected_item_spec)]),
             report_name: "".to_string(),
         };
